@@ -1,6 +1,10 @@
 #!/usr/bin/env python3
 # -*- coding: future_fstrings -*-
 
+"""
+Main script
+"""
+
 import argparse
 import os
 import sys
@@ -45,8 +49,16 @@ def get_arguments(args):
     :return:
     """
     parser = argparse.ArgumentParser(prog='db_sync_tool',
-                                     description=f'A tool for automatic database synchronization from '
-                                                 f'and to host systems.')
+                                     description='A tool for automatic database synchronization from '
+                                                 'and to host systems.')
+    parser.add_argument('origin',
+                        help='Origin database defined in host file',
+                        nargs='?',
+                        type=str)
+    parser.add_argument('target',
+                        help='Target database defined in host file',
+                        nargs='?',
+                        type=str)
     parser.add_argument('-f', '--config-file',
                         help='Path to configuration file',
                         required=False,
@@ -229,6 +241,12 @@ def build_config(args):
     if not args.type is None:
         config['type'] = args.type
 
+    if not args.origin is None:
+        config['link_origin'] = args.origin
+
+    if not args.target is None:
+        config['link_target'] = args.target
+
     if not args.target_path is None:
         config['target']['path'] = args.target_path
 
